LoadingStatus<T> class

A status indicating that the state is currently loading.

Inheritance
Available extensions

Constructors

LoadingStatus()

Properties

data → T?

Available on GetStatus<T>, provided by the StatusDataExt extension

Gets the data associated with the status if it is a success status.
no setter
errorMessage String

Available on GetStatus<T>, provided by the StatusDataExt extension

Gets the error message associated with the status.
no setter
hashCode int
The hash code for this object.
no setterinherited
isCustom bool

Available on GetStatus<T>, provided by the StatusDataExt extension

Checks if the status is a custom status.
no setter
isEmpty bool

Available on GetStatus<T>, provided by the StatusDataExt extension

Checks if the status indicates that the state is empty.
no setter
isError bool

Available on GetStatus<T>, provided by the StatusDataExt extension

Checks if the status indicates that the state has encountered an error.
no setter
isLoading bool

Available on GetStatus<T>, provided by the StatusDataExt extension

Checks if the status indicates that the state is loading.
no setter
isSuccess bool

Available on GetStatus<T>, provided by the StatusDataExt extension

Checks if the status indicates that the state is successful.
no setter
props List
The list of properties used for determining equality.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited